.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`color`
====================
.. automodule:: skimage.color

.. currentmodule:: skimage.color
.. autosummary::

   skimage.color.convert_colorspace
   skimage.color.guess_spatial_dimensions
   skimage.color.rgba2rgb
   skimage.color.rgb2hsv
   skimage.color.hsv2rgb
   skimage.color.rgb2xyz
   skimage.color.xyz2rgb
   skimage.color.rgb2rgbcie
   skimage.color.rgbcie2rgb
   skimage.color.rgb2grey
   skimage.color.rgb2gray
   skimage.color.gray2rgb
   skimage.color.grey2rgb
   skimage.color.xyz2lab
   skimage.color.lab2xyz
   skimage.color.lab2rgb
   skimage.color.rgb2lab
   skimage.color.rgb2hed
   skimage.color.hed2rgb
   skimage.color.lab2lch
   skimage.color.lch2lab
   skimage.color.rgb2yuv
   skimage.color.yuv2rgb
   skimage.color.rgb2yiq
   skimage.color.yiq2rgb
   skimage.color.rgb2ypbpr
   skimage.color.ypbpr2rgb
   skimage.color.rgb2ycbcr
   skimage.color.ycbcr2rgb
   skimage.color.rgb2ydbdr
   skimage.color.ydbdr2rgb
   skimage.color.separate_stains
   skimage.color.combine_stains
   skimage.color.label2rgb
   skimage.color.deltaE_cie76
   skimage.color.deltaE_ciede94
   skimage.color.deltaE_ciede2000
   skimage.color.deltaE_cmc



convert_colorspace
------------------

.. autofunction:: skimage.color.convert_colorspace


.. include:: skimage.color.convert_colorspace.examples

guess_spatial_dimensions
------------------------

.. autofunction:: skimage.color.guess_spatial_dimensions


.. include:: skimage.color.guess_spatial_dimensions.examples

rgba2rgb
--------

.. autofunction:: skimage.color.rgba2rgb


.. include:: skimage.color.rgba2rgb.examples

rgb2hsv
-------

.. autofunction:: skimage.color.rgb2hsv


.. include:: skimage.color.rgb2hsv.examples

hsv2rgb
-------

.. autofunction:: skimage.color.hsv2rgb


.. include:: skimage.color.hsv2rgb.examples

rgb2xyz
-------

.. autofunction:: skimage.color.rgb2xyz


.. include:: skimage.color.rgb2xyz.examples

xyz2rgb
-------

.. autofunction:: skimage.color.xyz2rgb


.. include:: skimage.color.xyz2rgb.examples

rgb2rgbcie
----------

.. autofunction:: skimage.color.rgb2rgbcie


.. include:: skimage.color.rgb2rgbcie.examples

rgbcie2rgb
----------

.. autofunction:: skimage.color.rgbcie2rgb


.. include:: skimage.color.rgbcie2rgb.examples

rgb2grey
--------

.. autofunction:: skimage.color.rgb2grey


.. include:: skimage.color.rgb2grey.examples

rgb2gray
--------

.. autofunction:: skimage.color.rgb2gray


.. include:: skimage.color.rgb2gray.examples

gray2rgb
--------

.. autofunction:: skimage.color.gray2rgb


.. include:: skimage.color.gray2rgb.examples

grey2rgb
--------

.. autofunction:: skimage.color.grey2rgb


.. include:: skimage.color.grey2rgb.examples

xyz2lab
-------

.. autofunction:: skimage.color.xyz2lab


.. include:: skimage.color.xyz2lab.examples

lab2xyz
-------

.. autofunction:: skimage.color.lab2xyz


.. include:: skimage.color.lab2xyz.examples

lab2rgb
-------

.. autofunction:: skimage.color.lab2rgb


.. include:: skimage.color.lab2rgb.examples

rgb2lab
-------

.. autofunction:: skimage.color.rgb2lab


.. include:: skimage.color.rgb2lab.examples

rgb2hed
-------

.. autofunction:: skimage.color.rgb2hed


.. include:: skimage.color.rgb2hed.examples

hed2rgb
-------

.. autofunction:: skimage.color.hed2rgb


.. include:: skimage.color.hed2rgb.examples

lab2lch
-------

.. autofunction:: skimage.color.lab2lch


.. include:: skimage.color.lab2lch.examples

lch2lab
-------

.. autofunction:: skimage.color.lch2lab


.. include:: skimage.color.lch2lab.examples

rgb2yuv
-------

.. autofunction:: skimage.color.rgb2yuv


.. include:: skimage.color.rgb2yuv.examples

yuv2rgb
-------

.. autofunction:: skimage.color.yuv2rgb


.. include:: skimage.color.yuv2rgb.examples

rgb2yiq
-------

.. autofunction:: skimage.color.rgb2yiq


.. include:: skimage.color.rgb2yiq.examples

yiq2rgb
-------

.. autofunction:: skimage.color.yiq2rgb


.. include:: skimage.color.yiq2rgb.examples

rgb2ypbpr
---------

.. autofunction:: skimage.color.rgb2ypbpr


.. include:: skimage.color.rgb2ypbpr.examples

ypbpr2rgb
---------

.. autofunction:: skimage.color.ypbpr2rgb


.. include:: skimage.color.ypbpr2rgb.examples

rgb2ycbcr
---------

.. autofunction:: skimage.color.rgb2ycbcr


.. include:: skimage.color.rgb2ycbcr.examples

ycbcr2rgb
---------

.. autofunction:: skimage.color.ycbcr2rgb


.. include:: skimage.color.ycbcr2rgb.examples

rgb2ydbdr
---------

.. autofunction:: skimage.color.rgb2ydbdr


.. include:: skimage.color.rgb2ydbdr.examples

ydbdr2rgb
---------

.. autofunction:: skimage.color.ydbdr2rgb


.. include:: skimage.color.ydbdr2rgb.examples

separate_stains
---------------

.. autofunction:: skimage.color.separate_stains


.. include:: skimage.color.separate_stains.examples

combine_stains
--------------

.. autofunction:: skimage.color.combine_stains


.. include:: skimage.color.combine_stains.examples

label2rgb
---------

.. autofunction:: skimage.color.label2rgb


.. include:: skimage.color.label2rgb.examples

deltaE_cie76
------------

.. autofunction:: skimage.color.deltaE_cie76


.. include:: skimage.color.deltaE_cie76.examples

deltaE_ciede94
--------------

.. autofunction:: skimage.color.deltaE_ciede94


.. include:: skimage.color.deltaE_ciede94.examples

deltaE_ciede2000
----------------

.. autofunction:: skimage.color.deltaE_ciede2000


.. include:: skimage.color.deltaE_ciede2000.examples

deltaE_cmc
----------

.. autofunction:: skimage.color.deltaE_cmc


.. include:: skimage.color.deltaE_cmc.examples

